@@ -506,6 +506,7 @@ class Messages(object):
 		self._itemView.setItemsExpandable(False)
 		self._itemView.setItemDelegate(self._htmlDelegate)
 		self._itemView.activated.connect(self._on_row_activated)
+		self._itemView.header().sectionResized.connect(self._on_column_resized)
 
 		self._layout = QtGui.QVBoxLayout()
 		self._layout.addLayout(self._selectionLayout)
@@ -595,11 +596,11 @@ class Messages(object):
 					for messagePart in messageParts
 				]
 
-			firstMessage = "<b>%s - %s</b> <i>(%s)</i>" % (name, prettyNumber, relTime)
+			firstMessage = "<b>%s<br/>%s</b> <i>(%s)</i>" % (name, prettyNumber, relTime)
 
 			expandedMessages = [firstMessage]
 			expandedMessages.extend(messages)
-			if (self._MIN_MESSAGES_SHOWN + 1) < len(messages):
+			if self._MIN_MESSAGES_SHOWN < len(messages):
 				secondMessage = "<i>%d Messages Hidden...</i>" % (len(messages) - self._MIN_MESSAGES_SHOWN, )
 				collapsedMessages = [firstMessage, secondMessage]
 				collapsedMessages.extend(messages[-(self._MIN_MESSAGES_SHOWN+0):])
@@ -668,6 +669,11 @@ class Messages(object):
 			numbersWithDescriptions = [(number, "")]
 			self._session.draft.add_contact(contactId, title, description, numbersWithDescriptions)
 
+	@QtCore.pyqtSlot(QtCore.QModelIndex)
+	@misc_utils.log_exception(_moduleLogger)
+	def _on_column_resized(self, index, oldSize, newSize):
+		self._htmlDelegate.setWidth(newSize)
+
 
 class Contacts(object):
 
